/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kmahjonggui.rc
  0x0,0x0,0x2,0x4e,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xba,0xb,0x25,0x12,0x0,0xf6,0x56,0x46,0x1f,0x30,0x91,0x1e,
  0xab,0x3d,0x9,0x9a,0x84,0xb3,0xc5,0xed,0x61,0x8b,0xa7,0x1a,0x29,0xfc,0xb2,0x38,
  0x3e,0xe2,0x3c,0x3c,0xe8,0x31,0x19,0x29,0xa8,0x6a,0x90,0x3,0x3f,0x0,0x3f,0x0,
  0x3b,0x0,0x1c,0x9f,0xaf,0x75,0xb2,0x52,0x41,0xc7,0x8c,0x20,0xcb,0x32,0xe7,0x12,
  0xd6,0xbd,0x54,0x83,0xec,0x1f,0x1e,0xa7,0x49,0xf9,0x14,0x43,0xf1,0xcc,0x34,0xa8,
  0x27,0xff,0xe3,0x97,0x7c,0x4e,0xb4,0x68,0x88,0x80,0x43,0x32,0x69,0x90,0x7c,0x8f,
  0x14,0x7e,0x3f,0x6d,0x20,0x20,0x34,0xe8,0xa9,0xdb,0xda,0xd8,0x53,0x4d,0xcd,0xe2,
  0x5,0x13,0x64,0x3c,0xf7,0x7a,0xf2,0x43,0x61,0x4d,0x6,0x44,0x57,0xd3,0xf7,0x45,
  0xad,0x27,0xcb,0xa8,0x72,0xe3,0xfa,0x96,0x9e,0xe3,0x44,0x2d,0x5a,0x8d,0xe0,0x71,
  0x9e,0xfa,0x65,0x48,0x21,0x36,0xe1,0xb6,0xe1,0x7b,0x80,0x67,0x53,0x30,0x2,0x91,
  0x2a,0x8e,0x30,0x18,0x14,0xc,0x99,0x5b,0x4d,0xc2,0xf9,0x25,0x33,0xce,0xc6,0x1a,
  0x6c,0x79,0xde,0x59,0x92,0xe8,0x3f,0xed,0x9d,0x2b,0x4a,0x25,0xcf,0x71,0x2d,0x83,
  0x5d,0xc9,0xe7,0x29,0x6b,0xa7,0x64,0xed,0x58,0x57,0x97,0xcb,0x45,0xd9,0x9,0xa3,
  0x12,0x46,0xa7,0x7b,0x95,0x5e,0x8f,0x3d,0xc5,0xca,0xd4,0xe2,0x5a,0xcb,0x6,0xc5,
  0x6f,0xcb,0xe2,0xa7,0x41,0xaf,0x3d,0xaf,0x9f,0xb2,0xfe,0x4e,0xe4,0x97,0xcc,0xc0,
  0xeb,0x5a,0xca,0xfa,0xfb,0x25,0x5a,0x8f,0xee,0xd1,0xd9,0xd1,0x76,0xa5,0xd0,0x52,
  0xb2,0x2b,0xb,0x7f,0x37,0x3b,0x6d,0xb8,0xb2,0xfa,0xf2,0x8d,0xb8,0x77,0xdf,0xa9,
  0xef,0xae,0xd0,0x56,0xd5,0x75,0xb1,0x17,0x5b,0x34,0x76,0xa5,0xf1,0xaf,0xc6,0xd8,
  0x46,0xa6,0x95,0x6b,0x35,0x7f,0xa0,0x61,0x8e,0x42,0x37,0xb,0xb,0xa,0x4a,0x95,
  0x65,0xc,0x30,0x84,0x10,0xc3,0x54,0xa9,0x7,0xa4,0xf0,0xdf,0x97,0x16,0xc8,0x5,
  0x3,0x2e,0x87,0x81,0x54,0x14,0x87,0x98,0xb,0xd5,0x3b,0x87,0xf9,0xb4,0xbd,0xa3,
  0x85,0x58,0x71,0x6e,0xd4,0xf2,0x63,0x85,0x86,0xd5,0x71,0xaf,0x25,0x51,0x10,0xcb,
  0x0,0x93,0x13,0x87,0x91,0xc2,0x1c,0xc9,0x76,0xb2,0x27,0x90,0x3c,0x41,0xb2,0x2c,
  0xe9,0x18,0x39,0xf1,0x88,0xf6,0xfd,0x60,0xbc,0x40,0xf1,0xb5,0xbc,0xd3,0x88,0xba,
  0xf7,0xd4,0xcf,0x8b,0xe5,0xdd,0x76,0x7c,0xd5,0x65,0xa1,0x32,0x9b,0xfb,0x32,0xd3,
  0x2d,0x4a,0xb7,0x21,0x80,0xe6,0x50,0x4e,0xa1,0x8b,0xd1,0x67,0x39,0xb6,0xed,0x18,
  0x9c,0x81,0xe6,0xd5,0x45,0x23,0xc2,0xd3,0x88,0x85,0x1a,0x4e,0xc8,0x32,0xeb,0x25,
  0x40,0xf4,0x7b,0x75,0xf4,0x9c,0x85,0x25,0x5c,0x36,0xb1,0x58,0xf2,0x4a,0x36,0x40,
  0x6,0x79,0x84,0xb1,0x32,0x43,0x2a,0x79,0x2,0x67,0x7b,0x89,0xa1,0xf3,0xdc,0xbe,
  0xdb,0xdc,0x82,0x38,0x2e,0xbe,0xf1,0x8b,0x46,0x17,0xe5,0x72,0xc9,0xe8,0x2e,0x14,
  0xb0,0x5,0xde,0x9a,0x62,0x80,0x80,0xfa,0x64,0x78,0xe9,0xfc,0x7d,0xe,0xc8,0x38,
  0x1c,0x4e,0x29,0x97,0x41,0x42,0x98,0x0,0xdd,0xc8,0xd1,0xee,0x63,0xcc,0xaf,0xa4,
  0x44,0x83,0x8b,0x61,0x1,0xe,0xad,0xc9,0x48,0x1c,0xf0,0x96,0x7c,0x39,0xa6,0x28,
  0x8f,0x86,0x46,0x39,0x24,0xef,0x85,0xd,0xc,0x70,0xa1,0xb4,0xb1,0xdf,0x63,0xe2,
  0x4e,0x38,0xb6,0x3b,0xe1,0x5c,0xd0,0x7a,0x14,0x38,0x89,0x45,0x2e,0x85,0x82,0x78,
  0xe0,0x0,0x5b,0xd,0x7c,0xde,0xd9,0xb8,0x88,0x43,0x70,0xff,0x91,0x63,0x9f,0xd,
  0x74,0x21,0x0,0xa8,0x4,0x99,0x96,0x7d,0x2b,0xc6,0x3,0x50,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kmahjongg
  0x0,0x9,
  0x7,0xf1,0xc0,0xb7,
  0x0,0x6b,
  0x0,0x6d,0x0,0x61,0x0,0x68,0x0,0x6a,0x0,0x6f,0x0,0x6e,0x0,0x67,0x0,0x67,
    // kmahjonggui.rc
  0x0,0xe,
  0xb,0x15,0xbd,0x83,
  0x0,0x6b,
  0x0,0x6d,0x0,0x61,0x0,0x68,0x0,0x6a,0x0,0x6f,0x0,0x6e,0x0,0x67,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x18,0xde,0xf2,0x20,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x18,0xde,0xf2,0x20,
  // :/kxmlgui5/kmahjongg
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x18,0xde,0xf2,0x20,
  // :/kxmlgui5/kmahjongg/kmahjonggui.rc
  0x0,0x0,0x0,0x2e,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x18,0xde,0xf2,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kmahjongg)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kmahjongg)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmahjongg)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmahjongg)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kmahjongg)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmahjongg)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
