/****************************************************************************
** Meta object code from reading C++ file 'gameview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmahjongg-26.04.3/src/gameview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8GameViewE_t {};
} // unnamed namespace

template <> constexpr inline auto GameView::qt_create_metaobjectdata<qt_meta_tag_ZN8GameViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GameView",
        "newGameCalculated",
        "",
        "statusTextChanged",
        "text",
        "gameNumber",
        "itemNumberChanged",
        "maxItemNum",
        "itemNum",
        "moveCount",
        "gameOver",
        "removedItems",
        "cheatsUsed",
        "demoOrMoveListAnimationOver",
        "demoGameLost",
        "noMovesAvailable",
        "addItemAndUpdate",
        "POSITION&",
        "stItemPos",
        "removeItem",
        "startDemo",
        "angleSwitchCCW",
        "angleSwitchCW",
        "createNewGame",
        "shuffle",
        "helpMove",
        "helpMatch",
        "const GameItem*",
        "gameItem",
        "startMoveListAnimation",
        "clearSelectedTile",
        "addItem",
        "updateImage",
        "updateOrder",
        "updatePosition",
        "GameItem*",
        "demoGameOver",
        "won",
        "changeItemSelectedState",
        "selected",
        "selectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newGameCalculated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusTextChanged'
        QtMocHelpers::SignalData<void(const QString &, long)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Long, 5 },
        }}),
        // Signal 'itemNumberChanged'
        QtMocHelpers::SignalData<void(int, int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'gameOver'
        QtMocHelpers::SignalData<void(unsigned short, unsigned short)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 11 }, { QMetaType::UShort, 12 },
        }}),
        // Signal 'demoOrMoveListAnimationOver'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'noMovesAvailable'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addItemAndUpdate'
        QtMocHelpers::SlotData<void(POSITION &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<void(POSITION &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'startDemo'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'angleSwitchCCW'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'angleSwitchCW'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createNewGame'
        QtMocHelpers::SlotData<void(long)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 5 },
        }}),
        // Slot 'createNewGame'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'shuffle'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'helpMove'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'helpMatch'
        QtMocHelpers::SlotData<void(const GameItem * const)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'startMoveListAnimation'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelectedTile'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(POSITION &, bool, bool, bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(POSITION &, bool, bool)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(POSITION &, bool)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(POSITION &)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(GameItem *, bool, bool, bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 28 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(GameItem *, bool, bool)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 35, 28 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(GameItem *, bool)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 35, 28 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(GameItem *)>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 35, 28 },
        }}),
        // Slot 'demoGameOver'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'changeItemSelectedState'
        QtMocHelpers::SlotData<void(POSITION &, bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 39 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GameView, qt_meta_tag_ZN8GameViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GameView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GameViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GameViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8GameViewE_t>.metaTypes,
    nullptr
} };

void GameView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GameView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newGameCalculated(); break;
        case 1: _t->statusTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<long>>(_a[2]))); break;
        case 2: _t->itemNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->gameOver((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ushort>>(_a[2]))); break;
        case 4: _t->demoOrMoveListAnimationOver((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->noMovesAvailable(); break;
        case 6: _t->addItemAndUpdate((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1]))); break;
        case 7: _t->removeItem((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1]))); break;
        case 8: _t->startDemo(); break;
        case 9: _t->angleSwitchCCW(); break;
        case 10: _t->angleSwitchCW(); break;
        case 11: _t->createNewGame((*reinterpret_cast<std::add_pointer_t<long>>(_a[1]))); break;
        case 12: _t->createNewGame(); break;
        case 13: _t->shuffle(); break;
        case 14: _t->helpMove(); break;
        case 15: _t->helpMatch((*reinterpret_cast<std::add_pointer_t<const GameItem*>>(_a[1]))); break;
        case 16: _t->startMoveListAnimation(); break;
        case 17: _t->clearSelectedTile(); break;
        case 18: _t->addItem((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 19: _t->addItem((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 20: _t->addItem((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->addItem((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1]))); break;
        case 22: _t->addItem((*reinterpret_cast<std::add_pointer_t<GameItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 23: _t->addItem((*reinterpret_cast<std::add_pointer_t<GameItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 24: _t->addItem((*reinterpret_cast<std::add_pointer_t<GameItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->addItem((*reinterpret_cast<std::add_pointer_t<GameItem*>>(_a[1]))); break;
        case 26: _t->demoGameOver((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->changeItemSelectedState((*reinterpret_cast<std::add_pointer_t<POSITION&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->selectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GameView::*)()>(_a, &GameView::newGameCalculated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GameView::*)(const QString & , long )>(_a, &GameView::statusTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GameView::*)(int , int , int )>(_a, &GameView::itemNumberChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GameView::*)(unsigned short , unsigned short )>(_a, &GameView::gameOver, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GameView::*)(bool )>(_a, &GameView::demoOrMoveListAnimationOver, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GameView::*)()>(_a, &GameView::noMovesAvailable, 5))
            return;
    }
}

const QMetaObject *GameView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8GameViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int GameView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void GameView::newGameCalculated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GameView::statusTextChanged(const QString & _t1, long _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void GameView::itemNumberChanged(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void GameView::gameOver(unsigned short _t1, unsigned short _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void GameView::demoOrMoveListAnimationOver(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void GameView::noMovesAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
